@@ -44,7 +44,7 @@ use std::ffi::OsString;
     after_help = "
 Basic examples:
   Command-line websocket client:
-    websocat ws://echo.websocket.org/
+    websocat ws://ws.vi-server.org/mirror/
     
   WebSocket server
     websocat -s 8080
@@ -499,6 +499,18 @@ struct Opt {
     /// [A] Wait for reading to finish before closing foreachmsg:'s peer
     #[structopt(long = "--foreachmsg-wait-read")]
     pub foreachmsg_wait_reads: bool,
+
+    /// [A] Print a line to stdout for each port being listened
+    #[structopt(long = "--stdout-announce-listening-ports")]
+    pub announce_listens: bool,
+
+    /// [A] Use monotonic clock for `timestamp:` overlay
+    #[structopt(long = "--timestamp-monotonic")]
+     pub timestamp_monotonic: bool,
+
+    /// Print measured round-trip-time to stderr after each received WebSocket pong.
+    #[structopt(long = "print-ping-rtts")]
+    pub print_ping_rtts: bool,
 }
 
 // TODO: make it byte-oriented/OsStr?
@@ -758,6 +770,9 @@ fn run() -> Result<()> {
             ws_text_base64
             asyncstdio
             foreachmsg_wait_reads
+            announce_listens
+            timestamp_monotonic
+            print_ping_rtts
         );
         #[cfg(feature = "ssl")]
         {
