@@ -94,4 +94,7 @@ pub struct Options {
     pub asyncstdio: bool,
 
     pub foreachmsg_wait_reads: bool,
+    pub announce_listens: bool,
+    pub timestamp_monotonic: bool,
+    pub print_ping_rtts: bool,
 }
